package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.dto.KlDiagnoseByIdDTO;
import com.diagbot.dto.KlDiagnoseGroupDTO;
import com.diagbot.dto.KlDiagnoseInfoDTO;
import com.diagbot.dto.KlDiagnoseTypeDTO;
import com.diagbot.entity.KlDiagnose;
import com.diagbot.entity.KlDiagnoseBase;
import com.diagbot.entity.KlDiagnoseCondition;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.KlDiagnoseServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.vo.KlDiagnoseByIdVO;
import com.diagbot.vo.KlDiagnoseClearVO;
import com.diagbot.vo.KlDiagnoseInfoVO;
import com.diagbot.vo.KlDiagnoseSatarDisVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Description:
 * @author: gaodm
 * @time: 2021/3/15 11:42
 */
@Component
public class KlDiagnoseFacade extends KlDiagnoseServiceImpl {
    @Autowired
    KlDiagnoseConditionFacade klDiagnoseConditionFacade;
    @Autowired
    KlDiagnoseBaseFacade klDiagnoseBaseFacade;
    @Autowired
    KlDictionaryInfoFacade klDictionaryInfoFacade;


    public IPage<KlDiagnoseInfoDTO> getKlDiagnoseInfoPage(KlDiagnoseInfoVO klDiagnoseInfoVO) {
        return this.getKlDiagnosePages(klDiagnoseInfoVO);

    }

    public List<KlDiagnoseTypeDTO> getByIdDiagnoseAll(KlDiagnoseByIdVO klDiagnoseByIdVO) {
        List<KlDiagnoseByIdDTO> byIdDiagnoses = this.getByIdDiagnoses(klDiagnoseByIdVO);
        //基础条件
        Map<Integer, List<KlDiagnoseByIdDTO>> baseGroupMap = byIdDiagnoses.stream().filter(i -> i.getConditionType().equals(1)).collect(Collectors.groupingBy(KlDiagnoseByIdDTO::getBaseGroup));
        //根据ConditionType 和 getConditionGroup两个添加分组
        Map<Integer, Map<Integer, List<KlDiagnoseByIdDTO>>> collect = byIdDiagnoses.stream().filter(i -> !i.getConditionType().equals(1)).collect(Collectors.groupingBy(KlDiagnoseByIdDTO::getConditionType, Collectors.groupingBy(KlDiagnoseByIdDTO::getConditionGroup)));

        List<KlDiagnoseTypeDTO> klDiagnoseTypeList = new ArrayList<>();
        for (Map.Entry<Integer, Map<Integer, List<KlDiagnoseByIdDTO>>> entry : collect.entrySet()) {
            KlDiagnoseTypeDTO klDiagnoseTypeDTO = new KlDiagnoseTypeDTO();
            klDiagnoseTypeDTO.setConditionType(entry.getKey());
            Map<Integer, List<KlDiagnoseByIdDTO>> value = entry.getValue();
            List<KlDiagnoseGroupDTO> byIdDTO = new ArrayList<>();
            for (Map.Entry<Integer, List<KlDiagnoseByIdDTO>> entry2 : value.entrySet()) {
                List<KlDiagnoseByIdDTO> value1 = entry2.getValue();
                for (KlDiagnoseByIdDTO data : value1) {
                    KlDiagnoseGroupDTO klDiagnoseGroupDTO = new KlDiagnoseGroupDTO();
                    klDiagnoseGroupDTO.setConditionGroup(entry2.getKey());
                    klDiagnoseGroupDTO.setFitNo(data.getFitNo());
                    klDiagnoseGroupDTO.setBaseGroup(data.getBaseGroup());
                    klDiagnoseGroupDTO.setKlDiagnoseByIdDTO(baseGroupMap.get(data.getBaseGroup()));
                    byIdDTO.add(klDiagnoseGroupDTO);

                }

                klDiagnoseTypeDTO.setByIdDTO(byIdDTO);
            }
            klDiagnoseTypeList.add(klDiagnoseTypeDTO);

        }
        return klDiagnoseTypeList;
    }

    public Boolean clearDiagnoseAll(KlDiagnoseClearVO klDiagnoseClearVO) {
        boolean res = false;
        res = clearDiagnoseSub(klDiagnoseClearVO.getId());
        //最后删除主表rule
        res = this.removeById(klDiagnoseClearVO.getId());
        return res;
    }

    private boolean clearDiagnoseSub(Long id) {
        boolean res = false;
        QueryWrapper<KlDiagnoseCondition> klDiagnoseConditionQuery = new QueryWrapper<>();
        klDiagnoseConditionQuery.eq("is_deleted", IsDeleteEnum.N.getKey()).eq("diagnose_id", id);
        List<KlDiagnoseCondition> diagnoseConditionList = klDiagnoseConditionFacade.list(klDiagnoseConditionQuery);
        List<Long> baseId = new ArrayList<>();
        if (ListUtil.isNotEmpty(diagnoseConditionList)) {
            for (KlDiagnoseCondition data : diagnoseConditionList) {
                if (null != data.getId()) {
                    baseId.add(data.getId());
                }
            }
        }
        if (ListUtil.isNotEmpty(baseId)) {
            QueryWrapper<KlDiagnoseBase> klDiagnoseBaseQuery = new QueryWrapper<>();
            klDiagnoseBaseQuery.eq("is_deleted", IsDeleteEnum.N.getKey()).in("id", baseId);
            //删除kl_rule_base表数据
            res = klDiagnoseBaseFacade.remove(klDiagnoseBaseQuery);

        }
        //删除kl_rule_condition表的数据
        res = klDiagnoseConditionFacade.remove(klDiagnoseConditionQuery);
        return res;
    }

    public Boolean disableDiagnose(KlDiagnoseSatarDisVO klDiagnoseSatarDisVO, int start) {
        boolean res = false;
        Date now = DateUtil.now();
        int sum = this.count(new QueryWrapper<KlDiagnose>().eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id", klDiagnoseSatarDisVO.getId()));
        if (sum == 0) {
            throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "该数据已不存在！");
        }
        UpdateWrapper<KlDiagnose> klKlDiagnoseUpdate = new UpdateWrapper<>();
        klKlDiagnoseUpdate.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id", klDiagnoseSatarDisVO.getId())
                .set("status", start)
                .set("gmt_modified", now);
        return this.update(new KlDiagnose(), klKlDiagnoseUpdate);
    }
}
